@@ -39,6 +39,9 @@ class RawData(object):
         if truth_buffer is None:
             truth_buffer = []
 
+        save_full_truth = self.config.get('save_full_truth', True)
+        log.debug(f"save_full_truth : {save_full_truth}")
+        
         # Pre-load some constents from config
         v = self.config['drift_velocity_liquid']
         rext = self.config['right_raw_extension']
@@ -104,14 +107,20 @@ class RawData(object):
 
                     if ptype == 1:
                         stop_at_this_group = True
-                        # Group S1 within 100 ns apart, truth info would be summarized within the group
-                        instb_run = np.split(instb_indx[ibqs[mask]],
-                                             np.where(np.diff(instb_time[ibqs[mask]]) > 100)[0] + 1)
+                        if save_full_truth:
+                            instb_run = np.split(instb_indx[ibqs[mask]], len(instb_indx[ibqs[mask]]))
+                        else:
+                            # Group S1 within 100 ns apart, truth info would be summarized within the group
+                            instb_run = np.split(instb_indx[ibqs[mask]],
+                                                 np.where(np.diff(instb_time[ibqs[mask]]) > 100)[0] + 1)
                     elif ptype == 2:
                         stop_at_this_group = True
-                        # Group S2 within 2 mm apart, truth info would be summarized within the group
-                        instb_run = np.split(instb_indx[ibqs[mask]], 
-                                             np.where(np.diff(instb_time[ibqs[mask]]) > int(0.2 / v))[0] + 1)
+                        if save_full_truth:
+                            instb_run = np.split(instb_indx[ibqs[mask]], len(instb_indx[ibqs[mask]]))
+                        else:
+                            # Group S2 within 2 mm apart, truth info would be summarized within the group
+                            instb_run = np.split(instb_indx[ibqs[mask]],
+                                                 np.where(np.diff(instb_time[ibqs[mask]]) > int(0.2 / v))[0] + 1)
                     else:
                         instb_run = [instb_indx[ibqs[mask]]]
 
@@ -342,19 +351,10 @@ class RawData(object):
                 (self.config['samples_before_pulse_center'] + self.config['samples_after_pulse_center'] + 1) \
                 * self.config['sample_duration']
 
-        channels = getattr(pulse, '_photon_channels', [])
-
-        n_dpe = getattr(pulse, '_n_double_pe', 0)
-        n_dpe_bot = getattr(pulse, '_n_double_pe_bot', 0)
-            
-        tb['n_photon'] -= np.sum(np.isin(channels, getattr(pulse, 'turned_off_pmts', [])))
-        tb['n_pe'] += tb['n_photon']+n_dpe
-        # this turned_off guy, check how this works with a config['turned_off_guys']
-        channels_bottom = list(
-            set(self.config['channels_bottom']).difference(getattr(pulse, 'turned_off_pmts', [])))
-        tb['n_photon_bottom'] = (
-            np.sum(np.isin(channels, channels_bottom)))
-        tb['n_pe_bottom'] = tb['n_photon_bottom'] + n_dpe_bot
+        # Copy single valued fields directly from pulse class
+        for field in ['n_pe', 'n_pe_trigger', 'n_photon', 'n_photon_trigger', 'raw_area', 'raw_area_trigger']:
+            for suffix in ['', '_bottom']:
+                tb[field+suffix] = getattr(pulse, '_' + field + suffix, 0)
 
         # Summarize the instruction cluster in one row of the truth file
         for field in instruction.dtype.names:
